Russole opened a new pull request, #11534:
URL: https://github.com/apache/ozone/pull/11534

   ## What changes were proposed in this pull request?
   * Create the MiniOzone HA cluster once in `@BeforeAll` instead of once per 
test.
   * Reset SCM node/address configuration in `@BeforeEach` to keep tests 
isolated.
   * Shut down the shared cluster in `@AfterAll`.
   
   ## What is the link to the Apache JIRA
   https://issues.apache.org/jira/browse/HDDS-16819
   
   ## How was this patch tested?
   * Test time: **31.649s**, compared with **259.1s** reported in JIRA.
   * Reduced by **227.451s** (**87.8%**), about **8.2x faster**.
   * CI Test: https://github.com/Russole/ozone/actions/runs/38401117068


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to